@@ -139,8 +139,8 @@ int Cube::def_met(string name, string uom, string descr, int parent_id) {
     // metv.push_back(met); /* append it to vector */
     metv[id] = met;
     return id;    
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException excep) {
+    cerr << excep;
     exit(1);
   }
 
@@ -167,8 +167,8 @@ Metric* Cube::create_met(int id, string name, string uom,
     //metv.push_back(met); /* append it to vector */
     metv[id] = met;
     return met;    
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException except) {
+    cerr << except;
     exit(1);
   }
 }
@@ -220,8 +220,8 @@ int Cube::def_region(string name, long beginln, long endln, string descr,
     regionv[id] = reg;
     mod->add_region(reg);
     return id;
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException except) {
+    cerr << except;
     exit(1);
   }
 }
@@ -250,8 +250,8 @@ Region* Cube::create_region(int id, string name, long beginln, long endln,
       }
     }
     return reg;
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException ex) {
+    cerr << ex;
     exit(1);
   }
 }
@@ -275,8 +275,8 @@ int Cube::def_csite(int modid, int line, int callee_id) {
     //csitev.push_back(csite);
     csitev[id] = csite;
     return id;
-  } catch (CUBException exception) {
-    cerr << exception;
+  } catch (CUBException ex) {
+    cerr << ex;
     exit(1);
   }  
 }
@@ -302,8 +302,8 @@ Callsite* Cube::create_csite(int id, int modid, int line,
     caller->add_csite(csite);
     csitev[id] = csite;
     return csite;
-  } catch (CUBException exception) {
-    cerr << exception;
+  } catch (CUBException ex) {
+    cerr << ex;
     exit(1);
   }  
 }
@@ -340,8 +340,8 @@ int Cube::def_cnode(int csite_id, int parent_id) {
     // cnodev.push_back(cnode);
     cnodev[id] = cnode;
     return id;
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException ex){
+    cerr << ex;
     exit(1);
   }  
 }
@@ -361,8 +361,8 @@ Cnode* Cube::create_cnode(int id, int csite_id, int parent_id) {
     else parent->add_child(cnode); // root entity
     cnodev[id] = cnode;
     return cnode;
-  } catch(CUBException exception) {
-    cerr << exception;
+  } catch(CUBException ex) {
+    cerr << ex;
     exit(1);
   }  
 }
@@ -687,8 +687,8 @@ const Location*  Cube::get_loc(int loc_id) {
 void Cube::print_severity(ostream& out) {
   map<int, Map2D>::iterator i;
   Map2D::iterator j;
-  map<int, double>::iterator k;
-  
+  // map<int, double>::iterator k;
+
   Map2D map2d;
   map<int, double> map1d;
   out.precision(6);
@@ -701,8 +701,11 @@ void Cube::print_severity(ostream& out) {
       out << "      <row cnodeId=\"" << j->first; // 6 space indent
       out << "\">" <<endl;
       map1d = j->second;
-      for (k = map1d.begin(); k!= map1d.end(); k++) {
+      /*for (k = map1d.begin(); k!= map1d.end(); k++) {
 	out << "        " << k->second << endl; // 8 space indent
+	}*/
+      for (int k = 0; k < thrdv.size(); k++) {
+	out << "        " <<  map1d[thrdv[k]->get_id()] << endl; // 8 space indent
       }
       out <<"      </row>" << endl;
     }
