@@ -168,7 +168,7 @@ void CubeCache::update_metforest_cache() {
     int pid = root->get_id();
     update_met_cache(pid);
   }
-  cout << "Performance Metric cache is updated" << endl;
+  // cout << "Performance Metric cache is updated" << endl;
 }
 
 void CubeCache::update_cnodeforest_cache(int met_state, int met_id) {
@@ -179,7 +179,7 @@ void CubeCache::update_cnodeforest_cache(int met_state, int met_id) {
     int id = root->get_id();
     update_cnode_cache(met_state, met_id, id);
   }
-  cout << "Cnode cache is updated" << endl;
+  // cout << "Cnode cache is updated" << endl;
 }
 
 // For displayed node: b in B; BxNxL
@@ -371,8 +371,20 @@ double CubeCache::sev(              int z, int b, int n, int l ) {
 }
 
 double CubeCache::get_vcsev(int mode[], int met_id, int cnode_id, int loc_id) {
-  if (cnode_id < 0) cnode_id = 0;
+  double sum = 0.0;
+  int cnid;
   if (loc_id   < 0) loc_id = 0;
+  if (cnode_id < 0) { // sum of the cnode roots
+    // cnode_id = 0;
+    vector<Cnode*>& cn_roots = cube->rcnodev;
+    for (int i = 0; i < cn_roots.size(); i++) {
+      Cnode* cur = cn_roots[i];
+      cnid = cur->get_id();
+      sum += sev(mode[CUBE_MET], CUBE_INCL, CUBE_INCL,
+		 met_id, cnid, loc_id);
+    }
+    return sum;
+  }
   // cout << "get_vcsev: " << mode[0] << "," << mode[1] << "," << mode[2] << endl;
   return sev(mode[CUBE_MET], mode[CUBE_PROG], mode[CUBE_LOC],
 		  met_id, cnode_id, loc_id);
